=======
Credits
=======

When you :doc:`contribute <index>` to icalendar, your name will appear as in the list of contributors, provided you have not set your GitHub profile to be anonymous.

The following people have made contributions to icalendar.
The maintainers of icalendar are grateful for their support.

Maintainers
-----------

- `@geier <https://github.com/geier>`_
- `@jacadzaca <https://github.com/jacadzaca>`_
- `Nicco Kunzmann <https://github.com/niccokunzmann>`_


Original author
---------------

- Max M <maxm@mxm.dk>


Contributors
------------

Become part of the list of :doc:`contributors <index>`.

.. image:: https://contrib.rocks/image?repo=collective/icalendar&max=120&columns=10
    :alt: icalendar contributors
    :target: https://github.com/collective/icalendar/graphs/contributors
    :loading: lazy


To print complete a list of all contributors sorted by their name and commit email address with their count of commits, issue the following command from your checkout.

.. code-block:: shell

    git shortlog -s -e


Supporters
----------

Financial support of the developers of icalendar makes it possible to add features, fix bugs, write documentation, and create an amazing community around the project.

We're grateful for the financial support of `Nicco Kunzmann <https://github.com/niccokunzmann>`_ by the following kind people and organizations through `Nicco's GitHub Sponsors page <https://github.com/sponsors/niccokunzmann>`_.

-   `Kraken Tech <https://github.com/kraken-tech>`_
-   `Abe Hanoka <https://github.com/abe-101>`_
-   `RPdenBoer <https://github.com/RPdenBoer>`_

You can also donate to the icalendar project through `icalendar's Open Collective donation page <https://opencollective.com/python-icalendar>`_.


History
-------
`Max M <http://www.mxm.dk>`_ had often needed to parse and generate iCalendar files.
Finally, he got tired of writing ad-hoc tools.
This package is his attempt at making an iCalendar package for Python.
The inspiration has come from the email package in the standard library, which he thinks is pretty simple, yet efficient and powerful.
